' ========================================================================================
' GdipCreateAdjustableArrowCap
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

' ========================================================================================
' The following example creates two AdjustableArrowCap objects, pArrowCapStart and
' pArrowCapEnd, and sets the fill mode to TRUE. The code then creates a Pen object and
' assigns pArrowCapStart as the starting line cap for this Pen object and pArrowCapEnd as
' the ending line cap. Next, draws a line.
' ========================================================================================
SUB GDIP_CreateAdjustableArrowCap (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pArrowPen AS DWORD
   LOCAL pArrowCapStart AS DWORD
   LOCAL pArrowCapEnd AS DWORD
   LOCAL fillstate AS LONG

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create an AdjustableArrowCap that is filled.
   hStatus = GdipCreateAdjustableArrowCap(10, 10, %TRUE, pArrowCapStart)
   ' // Create an AdjustableArrowCap that is not filled.
   hStatus = GdipCreateAdjustableArrowCap(15, 15, %FALSE, pArrowCapEnd)

   ' // Create a Pen.
   hStatus = GdipCreatePen1(GDIP_ARGB(255, 0, 0, 0), 1.0!, %UnitWorld, pArrowPen)

   ' Assign pArrowStart as the start cap.
   hStatus = GdipSetPenCustomStartCap(pArrowPen, pArrowCapStart)
   ' Assign pArrowEnd as the end cap.
   hStatus = GdipSetPenCustomEndCap(pArrowPen, pArrowCapEnd)

   ' // Draw a line using pArrowPen.
   hStatus = GdipDrawLineI(pGraphics, pArrowPen, 0, 0, 100, 100)

   ' // Cleanup
   IF pArrowCapStart THEN GdipDeleteCustomLineCap(pArrowCapStart)
   IF pArrowCapEnd THEN GdipDeleteCustomLineCap(pArrowCapEnd)
   IF pArrowPen THEN GdipDeletePen(pArrowPen)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   DIALOG NEW 0, "GdipCreateAdjustableArrowCap", , , 270, 170, %WS_OVERLAPPED OR %WS_THICKFRAME OR %WS_SYSMENU OR _
   %WS_MINIMIZEBOX OR %WS_MAXIMIZEBOX OR %WS_VISIBLE OR %DS_CENTER TO hDlg
   DIALOG SET COLOR hDlg, %BLACK, %WHITE
   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   LOCAL hDC AS DWORD
   LOCAL ps AS PAINTSTRUCT

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

      CASE %WM_PAINT
         hDC = BeginPaint(CBHNDL, ps)
         GDIP_CreateAdjustableArrowCap hDC
         EndPaint(CBHNDL, ps)

   END SELECT

END FUNCTION
' ========================================================================================
